==> delegate6.1.18.tar.gz: delegate6.1.18/src/delegate.c <==
/*////////////////////////////////////////////////////////////////////////
Copyright (c) 1994 Electrotechnical Laboratry (ETL), AIST, MITI

Permission to use, copy, modify, and distribute this material for any
purpose and without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies, and
that the name of ETL not be used in advertising or publicity pertaining
to this material without the specific, prior written permission of an
authorized representative of ETL.
ETL MAKES NO REPRESENTATIONS ABOUT THE ACCURACY OR SUITABILITY OF THIS
MATERIAL FOR ANY PURPOSE.  IT IS PROVIDED "AS IS", WITHOUT ANY EXPRESS
OR IMPLIED WARRANTIES.
/////////////////////////////////////////////////////////////////////////
Content-Type:	program/C; charset=US-ASCII
Program:	delegate (verbose delegate protocol)
Author:		Yutaka Sato <ysato@etl.go.jp>
Description:
History:
//////////////////////////////////////////////////////////////////////#*/
#include "delegate.h"
#include "ystring.h"

service_delegate(Conn)
	Connection *Conn;
{	char line[256];
	char com[256];
	char arg[256];
	FILE *fc,*tc;
	char host[256];
	char xhost[64],*pp;
	int xport;

	fc = fdopen(FromC,"r");
	tc = fdopen(ToC,  "w");

	ClientIF_name(Conn,FromC,host);
	/*gethostname(host,sizeof(host));*/
	sprintf(line,"%s %s\r\n",host,DELEGATE_Version());
	Fputs(line,tc);

/*
	Fputs("COMMANDS: \r\n",tc);
	Fputs("      telnet host [port]\r\n",tc);
	Fputs("      gopher [host port]\r\n",tc);
	Fputs("\r\n",tc);
*/

	while( fgetsTIMEOUT(line,sizeof(line),fc) != NULL ){
		DFLT_HOST[0] = 0;
		DFLT_PORT = 0;
		com[0] = 0;
		arg[0] = 0;
		sscanf(line,"%[^\r\n\t ]%*[\r\n\t ]%[^\r\n]",com,arg);

		if( strcasecmp(com,"QUIT") == 0 )
			break;
		if( strcasecmp(com,"TELNET") == 0 ){
			xport = 0;
			pp = wordScan(arg,xhost);
			sscanf(pp,"%d",&xport);
			set_SERVER(Conn,"telnet",xhost,xport);
			execSpecialist(Conn,FromC,tc,-1);
			break;
		}else
		if( strcasecmp(com,"PUBLIC") == 0 ){
			keepPublic(Conn,arg,FromC);
		}else
		if( Fputs(line,tc) == EOF )
			break;
	}
}

==> delegate9.0.3-pre13.tar.gz: delegate9.0.3-pre13/src/delegate.c <==
/*////////////////////////////////////////////////////////////////////////
Copyright (c) 1994 Electrotechnical Laboratry (ETL), AIST, MITI

Permission to use, copy, modify, and distribute this material for any
purpose and without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies, and
that the name of ETL not be used in advertising or publicity pertaining
to this material without the specific, prior written permission of an
authorized representative of ETL.
ETL MAKES NO REPRESENTATIONS ABOUT THE ACCURACY OR SUITABILITY OF THIS
MATERIAL FOR ANY PURPOSE.  IT IS PROVIDED "AS IS", WITHOUT ANY EXPRESS
OR IMPLIED WARRANTIES.
/////////////////////////////////////////////////////////////////////////
Content-Type:	program/C; charset=US-ASCII
Program:	delegate (verbose delegate protocol)
Author:		Yutaka Sato <ysato@etl.go.jp>
Description:
History:
//////////////////////////////////////////////////////////////////////#*/
#include "delegate.h"
#include "ystring.h"
#include "file.h"

int service_delegate(Connection *Conn)
{	CStr(line,256);
	CStr(com,256);
	CStr(arg,256);
	FILE *fc,*tc;
	CStr(host,256);
	CStr(xhost,64);
	const char *pp;
	int xport;

	fc = fdopen(FromC,"r");
	tc = fdopen(ToC,  "w");
	if( fc == NULL || tc == NULL )
		return 0;

	ClientIF_name(Conn,FromC,AVStr(host));
	/*gethostname(host,sizeof(host));*/
	sprintf(line,"%s %s\r\n",host,DELEGATE_Version());
	Fputs(line,tc);

/*
	Fputs("COMMANDS: \r\n",tc);
	Fputs("      telnet host [port]\r\n",tc);
	Fputs("      gopher [host port]\r\n",tc);
	Fputs("\r\n",tc);
*/

	while( fgetsTIMEOUT(AVStr(line),sizeof(line),fc) != NULL ){
		DFLT_HOST[0] = 0;
		DFLT_PORT = 0;
		com[0] = 0;
		arg[0] = 0;
		Xsscanf(line,"%[^\r\n\t ]%*[\r\n\t ]%[^\r\n]",AVStr(com),AVStr(arg));

		if( strcasecmp(com,"QUIT") == 0 )
			break;
		if( strcasecmp(com,"TELNET") == 0 ){
			xport = 0;
			pp = wordScan(arg,xhost);
			sscanf(pp,"%d",&xport);
			set_SERVER(Conn,"telnet",xhost,xport);
			execSpecialist(Conn,FromC,tc,-1);
			break;
		}else
		if( Fputs(line,tc) == EOF )
			break;
	}
	return 0;
}
